.. craft-platforms documentation root file

Craft Platforms
===============

.. toctree::
   :maxdepth: 1
   :hidden:

   reference/index

.. grid:: 1 1 2 2

   .. grid-item-card:: :ref:`Reference <reference>`

      **Technical information** about Craft Platforms

Project and community
=====================

Craft Platforms is a member of the Canonical family. It's an open source project
that warmly welcomes community projects, contributions, suggestions, fixes
and constructive feedback.

* `Ubuntu Code of Conduct <https://ubuntu.com/community/code-of-conduct>`_.
* `Canonical contributor licenses agreement
  <https://ubuntu.com/legal/contributors>`_.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
